Module engine

Module engine 

Bridges the async, Tokio-based netrunner_core engine to GPUI.

GPUI runs its own (non-Tokio) executor, while netrunner-core uses reqwest which requires a Tokio runtime. We therefore run the speed test on a dedicated background thread with its own multi-threaded Tokio runtime and stream TestEvents back over a futures channel that GPUI can poll from its foreground executor.

Functions

spawn_speed_test
Start a speed test on a background Tokio runtime.