spawn_speed_test

Function spawn_speed_test 

pub fn spawn_speed_test(config: TestConfig) -> UnboundedReceiver<TestEvent>
Start a speed test on a background Tokio runtime.

Returns a stream of TestEvents. The test begins immediately; drop the receiver to stop caring about its progress (the background thread finishes on its own).